@@ -4,15 +4,15 @@ import logging
 import pytest
 from clvm.casts import int_to_bytes
 
-from src.consensus.blockchain import ReceiveBlockResult
-from src.protocols import full_node_protocol
-from src.types.announcement import Announcement
-from src.types.condition_opcodes import ConditionOpcode
-from src.types.condition_var_pair import ConditionVarPair
-from src.types.spend_bundle import SpendBundle
-from src.util.errors import ConsensusError, Err
-from src.util.ints import uint64
-from src.util.wallet_tools import WalletTool
+from chia.consensus.blockchain import ReceiveBlockResult
+from chia.protocols import full_node_protocol
+from chia.types.announcement import Announcement
+from chia.types.condition_opcodes import ConditionOpcode
+from chia.types.condition_var_pair import ConditionVarPair
+from chia.types.spend_bundle import SpendBundle
+from chia.util.errors import ConsensusError, Err
+from chia.util.ints import uint64
+from chia.util.wallet_tools import WalletTool
 from tests.core.full_node.test_full_node import connect_and_get_peer
 from tests.setup_nodes import bt, setup_two_nodes, test_constants
 
