@@ -2,17 +2,17 @@ import asyncio
 
 import pytest
 
-from src.consensus.block_rewards import calculate_base_farmer_reward, calculate_pool_reward
-from src.consensus.blockchain import ReceiveBlockResult
-from src.protocols import full_node_protocol, wallet_protocol
-from src.protocols.protocol_message_types import ProtocolMessageTypes
-from src.simulator.full_node_simulator import FullNodeSimulator
-from src.simulator.simulator_protocol import FarmNewBlockProtocol
-from src.types.mempool_inclusion_status import MempoolInclusionStatus
-from src.types.peer_info import PeerInfo
-from src.util.errors import Err
-from src.util.ints import uint16, uint32
-from src.wallet.transaction_record import TransactionRecord
+from chia.consensus.block_rewards import calculate_base_farmer_reward, calculate_pool_reward
+from chia.consensus.blockchain import ReceiveBlockResult
+from chia.protocols import full_node_protocol, wallet_protocol
+from chia.protocols.protocol_message_types import ProtocolMessageTypes
+from chia.simulator.full_node_simulator import FullNodeSimulator
+from chia.simulator.simulator_protocol import FarmNewBlockProtocol
+from chia.types.mempool_inclusion_status import MempoolInclusionStatus
+from chia.types.peer_info import PeerInfo
+from chia.util.errors import Err
+from chia.util.ints import uint16, uint32
+from chia.wallet.transaction_record import TransactionRecord
 from tests.core.full_node.test_full_node import add_dummy_connection
 from tests.setup_nodes import bt, self_hostname, setup_simulators_and_wallets
 from tests.time_out_assert import time_out_assert
